{% for doc in documents %}
      <tr {% if documents.count > 10 %} {% if forloop.last %} hx-get="{{ url }}?page={{ page_obj.number|add:1 }}" hx-trigger="revealed" hx-swap="afterend" hx-target="this" {% endif %}{% endif %} class="{% cycle 'table-secondary' '' %}"> <td><a href="" hx-get="{% url 'documentation' doc.title_slug %}" hx-target="#documentationModal .modal-body" hx-trigger="click" data-bs-toggle="modal" data-bs-target="#documentationModal">{{ doc.title }}</a></td>
        <td>{{ doc.updated_by }}</td>
        <td>{{ doc.updated_at }}</td>
      </tr>
{% endfor %}