<div class="markdownx row">
    <div class="col-md-6">
        {% include 'django/forms/widgets/textarea.html' %}
    </div>
    <div class="col-md-6">
        <div class="markdownx-preview p-3 border bg-light" style="overflow-y: auto;">

        </div>
    </div>
</div>